@@ -14,6 +14,8 @@
 import click
 
 from lean.commands.cloud.backtest import backtest
+from lean.commands.cloud.live import live
+from lean.commands.cloud.optimize import optimize
 from lean.commands.cloud.pull import pull
 from lean.commands.cloud.push import push
 
@@ -29,3 +31,5 @@ def cloud() -> None:
 cloud.add_command(pull)
 cloud.add_command(push)
 cloud.add_command(backtest)
+cloud.add_command(optimize)
+cloud.add_command(live)
