@@ -21,7 +21,8 @@ from lean.container import container
 from lean.models.api import (QCEmailNotificationMethod, QCNode, QCNotificationMethod, QCSMSNotificationMethod,
                              QCWebhookNotificationMethod)
 from lean.models.brokerages import (BitfinexBrokerage, CloudBrokerage, CoinbaseProBrokerage, FXCMBrokerage,
-                                    InteractiveBrokersBrokerage, OANDABrokerage, PaperTradingBrokerage)
+                                    InteractiveBrokersBrokerage, OANDABrokerage, PaperTradingBrokerage,
+                                    TradierBrokerage)
 from lean.models.logger import Option
 
 
@@ -111,6 +112,7 @@ def live(project: str, push: bool, open_browser: bool) -> None:
     brokerages = [
         PaperTradingBrokerage(),
         InteractiveBrokersBrokerage(),
+        TradierBrokerage(),
         FXCMBrokerage(),
         OANDABrokerage(),
         BitfinexBrokerage(),
@@ -128,7 +130,8 @@ def live(project: str, push: bool, open_browser: bool) -> None:
 
     live_nodes = [node for node in nodes.live if not node.busy]
     if len(live_nodes) == 0:
-        raise RuntimeError("You don't have any live nodes available")
+        raise RuntimeError(
+            "You don't have any live nodes available, you can manage your nodes on https://www.quantconnect.com/terminal/#organization/resources")
 
     node_options = [Option(id=node, label=f"{node.name} - {node.description}") for node in nodes.live]
     node: QCNode = logger.prompt_list("Select a node", node_options)
