@@ -12,13 +12,16 @@
 # limitations under the License.
 
 import json
+import os
 import platform
 import sys
+from datetime import datetime, timezone
 from pathlib import Path
+from typing import List
 from xml.etree import ElementTree
 
 from lean.components.config.project_config_manager import ProjectConfigManager
-from lean.models.api import QCLanguage
+from lean.models.api import QCLanguage, QCProject
 
 
 class ProjectManager:
@@ -49,6 +52,64 @@ class ProjectManager:
 
         raise ValueError("The specified project does not contain a main.py or Main.cs file")
 
+    def get_files_to_sync(self, project: Path) -> List[Path]:
+        """Returns the paths of all the local files that need to be synchronized with the cloud.
+
+        :param project: the path to a local project directory
+        :return: the list of files in the given project directory that need to be synchronized with the cloud
+        """
+        local_files = list(project.rglob("*.py")) + list(project.rglob("*.cs")) + list(project.rglob("*.ipynb"))
+        files_to_sync = []
+
+        for local_file in local_files:
+            posix_path = local_file.as_posix()
+            if "bin/" in posix_path or "obj/" in posix_path or ".ipynb_checkpoints/" in posix_path:
+                continue
+
+            files_to_sync.append(local_file)
+
+        return files_to_sync
+
+    def should_sync_files(self, local_project: Path, cloud_project: QCProject) -> bool:
+        """Returns whether there are files to synchronize based on last modified times.
+
+        Without the logic in this method the pull/push flow looks like this:
+        1. Retrieve all project information from projects/read endpoint
+        2. For each project, retrieve all remote files from files/read endpoint
+        3. For each file, check if the local content differs from the remote content
+
+        This method uses the last modified times of local files and the information retrieved in step 1 to
+        skip step 2 and 3 for projects of which we know there is nothing to pull/push. This lowers the
+        amount of API requests, speeds up pull/push (especially if the user has a lot of projects).
+
+        This method is not perfect as it may return True if there are no updates to pull/push.
+        This happens due to the limited amount of information that is available after step 1.
+        In that case the only way to know whether there is something to sync is by querying the files/read endpoint.
+
+        :param local_project: the path to the local project directory
+        :param cloud_project: the cloud counterpart of the local project
+        :return: True if there may be updates to synchronize, False if not
+        """
+        paths_to_check = [local_project] + self.get_files_to_sync(local_project)
+
+        last_modified_time = max((file.stat().st_mtime_ns / 1e9) for file in paths_to_check)
+        last_modified_time = datetime.fromtimestamp(last_modified_time).astimezone(tz=timezone.utc)
+
+        # If the last modified time of the local files equal the last modified time of the project,
+        # we can safely assume there are no changes to pull/push.
+        return last_modified_time.replace(tzinfo=None, microsecond=0) != cloud_project.modified
+
+    def update_last_modified_time(self, local_file_path: Path, cloud_timestamp: datetime) -> None:
+        """Updates the last modified time of a local path to that of the cloud counterpart.
+
+        :param local_file_path: the path to the local file to update the last modified time of
+        :param cloud_timestamp: the last modified time of the counterpart of the local file in the cloud
+        """
+        # Timestamps are stored in UTC in the cloud, but utime() requires them in the local timezone
+        time = cloud_timestamp.replace(tzinfo=timezone.utc).astimezone(tz=None)
+        time = round(time.timestamp() * 1e9)
+        os.utime(local_file_path, ns=(time, time))
+
     def create_new_project(self, project_dir: Path, language: QCLanguage) -> None:
         """Creates a new project directory and fills it with some useful files.
 
@@ -336,7 +397,7 @@ on the page above, you can add a PackageReference for it.
 
         :param project_dir: the directory of the new project
         """
-        self._generate_file(project_dir / ".idea" / f".idea.{project_dir.name}.dir" / ".idea" / "workspace.xml", """
+        workspace_xml = """
 <?xml version="1.0" encoding="UTF-8"?>
 <project version="4">
   <component name="RunManager">
@@ -350,7 +411,12 @@ on the page above, you can add a PackageReference for it.
     </configuration>
   </component>
 </project>
-        """)
+        """
+
+        self._generate_file(project_dir / ".idea" / f".idea.{project_dir.name}" / ".idea" / "workspace.xml",
+                            workspace_xml)
+        self._generate_file(project_dir / ".idea" / f".idea.{project_dir.name}.dir" / ".idea" / "workspace.xml",
+                            workspace_xml)
 
     def _generate_file(self, file: Path, content: str) -> None:
         """Writes to a file, which is created if it doesn't exist yet, and normalized the content before doing so.
